auctex-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[AUCTeX-diffs] Changes to auctex/tex.el,v


From: Tassilo Horn
Subject: [AUCTeX-diffs] Changes to auctex/tex.el,v
Date: Sun, 05 Jun 2011 08:49:27 +0000

CVSROOT:        /sources/auctex
Module name:    auctex
Changes by:     Tassilo Horn <tsdh>     11/06/05 08:49:26

Index: tex.el
===================================================================
RCS file: /sources/auctex/auctex/tex.el,v
retrieving revision 5.680
retrieving revision 5.681
diff -u -b -r5.680 -r5.681
--- tex.el      15 May 2011 20:16:55 -0000      5.680
+++ tex.el      5 Jun 2011 08:49:26 -0000       5.681
@@ -1419,9 +1419,14 @@
 emitted from the Evince document viewer.  IGNORED absorbs an
 unused id field accompanying the DBUS signal sent by Evince-3.0.0
 or newer."
-  ;; FILE is actually given as relative path to the TeX-master root document,
-  ;; so we need to strip the directory part to match the buffer name.
-  (let ((buf (get-buffer (file-name-nondirectory file)))
+  ;; FILE may be given as relative path to the TeX-master root document or as
+  ;; absolute file:// URL.  In the former case, the tex file has to be already
+  ;; opened.
+  (require 'url-parse)
+  (let ((buf (let ((f (aref (url-generic-parse-url file) 6)))
+              (if (file-name-absolute-p f)
+                  (find-file f)
+                (get-buffer (file-name-nondirectory file)))))
         (line (car linecol))
         (col (cadr linecol)))
     (if (null buf)



reply via email to

[Prev in Thread] Current Thread [Next in Thread]